Jn_array

Function Jn_array 

pub fn Jn_array(
    nmin: u32,
    nmax: u32,
    x: f64,
    result_array: &mut [f64],
) -> Result<(), Value>
This routine computes the values of the regular cylindrical Bessel functions J_n(x) for n from nmin to nmax inclusive, storing the results in the array result_array. The values are computed using recurrence relations for efficiency, and therefore may differ slightly from the exact values.