Kn_array

Function Kn_array 

pub fn Kn_array(
    nmin: u32,
    nmax: u32,
    x: f64,
    result_array: &mut [f64],
) -> Result<(), Value>
This routine computes the values of the irregular modified cylindrical Bessel functions K_n(x) for n from nmin to nmax inclusive, storing the results in the array result_array. The start of the range nmin must be positive or zero. The domain of the function is x>0. The values are computed using recurrence relations for efficiency, and therefore may differ slightly from the exact values.