pub fn jl_array(
lmax: u32,
x: f64,
result_array: &mut [f64],
) -> Result<(), Value>Expand description
This routine computes the values of the regular spherical Bessel functions j_l(x) for l from 0 to lmax inclusive for lmax >= 0 and x >= 0, storing the results in the array result_array. The values are computed using recurrence relations for efficiency, and therefore may differ slightly from the exact values.