yl_array

Function yl_array 

pub fn yl_array(
    lmax: u32,
    x: f64,
    result_array: &mut [f64],
) -> Result<(), Value>
This routine computes the values of the irregular spherical Bessel functions y_l(x) for l from 0 to lmax inclusive for lmax >= 0, storing the results in the array result_array. The values are computed using recurrence relations for efficiency, and therefore may differ slightly from the exact values.