Function rgsl::filter::gaussian_kernel [−][src]
pub fn gaussian_kernel(
alpha: f64,
order: usize,
normalize: bool,
kernel: &mut VectorF64
) -> ValueThis is supported on crate feature
v2_5 only.Expand description
This function constructs a Gaussian kernel parameterized by alpha and stores the output in
kernel. The parameter order specifies the derivative order, with 0 corresponding to a
Gaussian, 1 corresponding to a first derivative Gaussian, and so on. If normalize is set to
true, then the kernel will be normalized to sum to one on output. If normalize is set to
false, no normalization is performed.