Function rgsl::linear_algebra::hessenberg_set_zero [−][src]
pub fn hessenberg_set_zero(h: &mut MatrixF64) -> ValueExpand description
This function sets the lower triangular portion of H, below the subdiagonal, to zero. It is useful for clearing out the Householder vectors after calling gsl_linalg_hessenberg_decomp.