pub fn poly_complex_eval(c: &[f64], z: &ComplexF64) -> ComplexF64Expand description
This function evaluates a polynomial with real coefficients for the complex variable z.
pub fn poly_complex_eval(c: &[f64], z: &ComplexF64) -> ComplexF64This function evaluates a polynomial with real coefficients for the complex variable z.