Function rgsl::polynomials::evaluation::poly_eval
source · Expand description
This function evaluates a polynomial with real coefficients for the real variable x.
This function evaluates a polynomial with real coefficients for the real variable x.