sort_largest

Function sort_largest 

pub fn sort_largest(
    dest: &mut [f64],
    k: usize,
    src: &[f64],
    stride: usize,
) -> Result<(), Value>
This function copies the k largest elements of the array src, of size n and stride stride, in descending numerical order into the array dest. k must be less than or equal to n. The data src is not modified by this operation.