Function rgsl::sort::select::sort_smallest [−][src]
pub fn sort_smallest(
dest: &mut [f64],
k: usize,
src: &[f64],
stride: usize
) -> ValueExpand description
This function copies the k smallest elements of the array src, of size n and stride stride, in ascending numerical order into the array dest. The size k of the subset must be less than or equal to n. The data src is not modified by this operation.