sort_vector_largest

Function sort_vector_largest 

pub fn sort_vector_largest(
    dest: &mut [f64],
    k: usize,
    v: &VectorF64,
) -> Result<(), Value>
This function copies the k smallest or largest elements of the vector v into the array dest. k must be less than or equal to the length of the vector v.