Function rgsl::sort::select::sort_vector_largest_index [−][src]
pub fn sort_vector_largest_index(
p: &mut [usize],
k: usize,
v: &VectorF64
) -> ValueExpand description
This function stores the indices of the k smallest or largest elements of the vector v in the array p. k must be less than or equal to the length of the vector v.