Function rgsl::sort::vectors::sort [−][src]
pub fn sort(data: &mut [f64], stride: usize, n: usize)Expand description
This function sorts the n elements of the array data with stride stride into ascending numerical order.