absdev_m

Function absdev_m 

pub fn absdev_m(data: &[f64], stride: usize, n: usize, mean: f64) -> f64
This function computes the absolute deviation of the dataset data relative to the given value of mean,

absdev = (1/N) \sum |x_i - mean|

This function is useful if you have already computed the mean of data (and want to avoid recomputing it), or wish to calculate the absolute deviation relative to another value (such as zero, or the median).