Struct rgsl::types::interpolation::InterpAccel [−][src]
pub struct InterpAccel(pub gsl_interp_accel);Expand description
Evaluation accelerator.
Tuple Fields
0: gsl_interp_accelImplementations
This function returns a pointer to an accelerator object, which is a kind of iterator for interpolation lookups. It tracks the state of lookups, thus allowing for application of various acceleration strategies.
This function reinitializes the accelerator object acc. It should be used when the cached information is no longer applicable-for example, when switching to a new dataset.
This function performs a lookup action on the data array x_array of size size, using the
given accelerator a. This is how lookups are performed during evaluation of an
interpolation. The function returns an index i such that x_array[i] <= x < x_array[i+1].