Struct rgsl::types::multiroot::MultiRootFSolver [−][src]
pub struct MultiRootFSolver<'a> { /* fields omitted */ }Expand description
This is a workspace for multidimensional root-finding without derivatives.
Implementations
This function returns a pointer to a newly allocated instance of a solver of type T with
n unknowns.
If there is insufficient memory to create the solver then the function returns a null
pointer and the error handler is invoked with an error code of Value::NoMemory.
This function initializes, or reinitializes, an existing solver s to use the multi
function f with n unknowns.
This function performs a single iteration of the minimizer s. If the iteration encounters an unexpected problem then an error code will be returned,
::Value::BadFunc the iteration encountered a singular point where the function evaluated to Inf or NaN.
::Value::Failure the algorithm could not improve the current best approximation or bounding interval.
The minimizer maintains a current best estimate of the position of the minimum at all times, and the current interval bounding the minimum. This information can be accessed with the following auxiliary functions,
This function returns the current estimate of the root for the solver s, given by s->x.
This function returns the last step dx taken by the solver s, given by s->dx.