pub fn In_array(
nmin: u32,
nmax: u32,
x: f64,
result_array: &mut [f64],
) -> Result<(), Value>Expand description
This routine computes the values of the regular modified cylindrical Bessel functions I_n(x) for n from nmin to nmax inclusive, storing the results in the array result_array. The start of the range nmin must be positive or zero. The values are computed using recurrence relations for efficiency, and therefore may differ slightly from the exact values.