pub fn Yn_array(
nmin: u32,
nmax: u32,
x: f64,
result_array: &mut [f64],
) -> Result<(), Value>Expand description
This routine computes the values of the irregular cylindrical Bessel functions Y_n(x) for n from nmin to nmax inclusive, storing the results in the array result_array. The domain of the function is x>0. The values are computed using recurrence relations for efficiency, and therefore may differ slightly from the exact values.