Struct rgsl::types::multifit_solver::MultiFitFdfSolver [−][src]
pub struct MultiFitFdfSolver { /* fields omitted */ }Implementations
This function returns a pointer to a newly allocated instance of a solver of type T for n observations and p parameters. The number of observations n must be greater than or equal to parameters p.
This function initializes, or reinitializes, an existing solver s to use the function f and the initial guess x.
This function performs a single iteration of the solver s. If the iteration encounters an unexpected problem then an error code will be returned. The solver maintains a current estimate of the best-fit parameters at all times.
This function returns the current position (i.e. best-fit parameters) s->x of the solver s.